Struct mysql_async::Pool
[−]
[src]
pub struct Pool { /* fields omitted */ }Asynchronous pool of MySql connections.
Methods
impl Pool[src]
fn new<O: Into<Opts>>(opts: O, handle: &Handle) -> Pool
Creates new pool of connections.
fn get_conn(&self) -> GetConn
Returns future that resolves to Conn.
fn disconnect(self) -> DisconnectPool
Returns future that disconnects this pool from server and resolves to ().
Active connections taken from this pool should be disconnected manually.
Also all pending and new GetConn's will resolve to error.